@@ -40,20 +40,35 @@ type mockRunner struct {
 
 func (r *mockRunner) Build(ctx context.Context, out io.Writer, artifacts []*latest.Artifact) ([]graph.Artifact, error) {
 	out.Write([]byte("Build Completed"))
-	return []graph.Artifact{{
-		ImageName: "gcr.io/skaffold/example",
-		Tag:       "test",
-	}}, nil
+	graphArtifacts := make([]graph.Artifact, len(artifacts))
+	for i, a := range artifacts {
+		graphArtifacts[i] = graph.Artifact{
+			ImageName:   a.ImageName,
+			Tag:         "test",
+			RuntimeType: a.RuntimeType,
+		}
+	}
+	return graphArtifacts, nil
 }
 
 func (r *mockRunner) Stop() error {
 	return nil
 }
 
-func TestTagFlag(t *testing.T) {
-	mockCreateRunner := func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
-		return &mockRunner{}, []util.VersionedConfig{&latest.SkaffoldConfig{}}, nil, nil
+func newMockCreateRunner(artifacts []*latest.Artifact) func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
+	return func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
+		return &mockRunner{}, []util.VersionedConfig{&latest.SkaffoldConfig{
+			Pipeline: latest.Pipeline{
+				Build: latest.BuildConfig{
+					Artifacts: artifacts,
+				},
+			},
+		}}, nil, nil
 	}
+}
+
+func TestTagFlag(t *testing.T) {
+	mockCreateRunner := newMockCreateRunner([]*latest.Artifact{{ImageName: "gcr.io/skaffold/example"}})
 
 	testutil.Run(t, "override tag with argument", func(t *testutil.T) {
 		t.Override(&quietFlag, true)
@@ -70,9 +85,7 @@ func TestTagFlag(t *testing.T) {
 }
 
 func TestQuietFlag(t *testing.T) {
-	mockCreateRunner := func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
-		return &mockRunner{}, []util.VersionedConfig{&latest.SkaffoldConfig{}}, nil, nil
-	}
+	mockCreateRunner := newMockCreateRunner([]*latest.Artifact{{ImageName: "gcr.io/skaffold/example"}})
 
 	tests := []struct {
 		description    string
@@ -116,9 +129,7 @@ func TestQuietFlag(t *testing.T) {
 }
 
 func TestFileOutputFlag(t *testing.T) {
-	mockCreateRunner := func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
-		return &mockRunner{}, []util.VersionedConfig{&latest.SkaffoldConfig{}}, nil, nil
-	}
+	mockCreateRunner := newMockCreateRunner([]*latest.Artifact{{ImageName: "gcr.io/skaffold/example"}})
 
 	tests := []struct {
 		description         string
@@ -182,9 +193,7 @@ func TestRunBuild(t *testing.T) {
 	errRunner := func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
 		return nil, nil, nil, errors.New("some error")
 	}
-	mockCreateRunner := func(context.Context, io.Writer, config.SkaffoldOptions) (runner.Runner, []util.VersionedConfig, *runcontext.RunContext, error) {
-		return &mockRunner{}, []util.VersionedConfig{&latest.SkaffoldConfig{}}, nil, nil
-	}
+	mockCreateRunner := newMockCreateRunner([]*latest.Artifact{{ImageName: "gcr.io/skaffold/example"}})
 
 	tests := []struct {
 		description string
@@ -212,3 +221,22 @@ func TestRunBuild(t *testing.T) {
 		})
 	}
 }
+
+func TestRuntimeType(t *testing.T) {
+	mockCreateRunner := newMockCreateRunner([]*latest.Artifact{{
+		ImageName:   "gcr.io/skaffold/example",
+		RuntimeType: "go",
+	}})
+
+	testutil.Run(t, "set runtime type on artifact", func(t *testutil.T) {
+		t.Override(&quietFlag, true)
+		t.Override(&createRunner, mockCreateRunner)
+
+		var output bytes.Buffer
+
+		err := doBuild(context.Background(), &output)
+
+		t.CheckNoError(err)
+		t.CheckDeepEqual(string([]byte(`{"builds":[{"imageName":"gcr.io/skaffold/example","tag":"test","runtimeType":"go"}]}`)), output.String())
+	})
+}
