@@ -14,11 +14,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-files=$(find . -name "*.go" | grep -v vendor/ | xargs gofmt -l -s)
+files=$(find . -name "*.go" | grep -vE '\.\/fs\/|\.\/vendor\/' | xargs gofmt -l -s)
 if [[ $files ]]; then
     echo "Gofmt errors in files:"
     echo "$files"
-    diff=$(find . -name "*.go" | grep -v vendor/ | xargs gofmt -w -d)
+    diff=$(find . -name "*.go" | grep -vE '\.\/fs\/|\.\/vendor\/' | xargs gofmt -w -d)
     echo "$diff"
     exit 1
 fi
