@@ -21,8 +21,8 @@ import (
 
 	yaml "gopkg.in/yaml.v3"
 
-	"github.com/GoogleContainerTools/skaffold/integration/skaffold"
-	"github.com/GoogleContainerTools/skaffold/testutil"
+	"github.com/GoogleContainerTools/skaffold/v2/integration/skaffold"
+	"github.com/GoogleContainerTools/skaffold/v2/testutil"
 )
 
 func TestFilterPassthrough(t *testing.T) {
