@@ -34,9 +34,9 @@ import (
 	fakekubeclientset "k8s.io/client-go/kubernetes/fake"
 	appsclient "k8s.io/client-go/kubernetes/typed/apps/v1"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/diag/recommender"
-	"github.com/GoogleContainerTools/skaffold/proto/v1"
-	"github.com/GoogleContainerTools/skaffold/testutil"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/diag/recommender"
+	"github.com/GoogleContainerTools/skaffold/v2/proto/v1"
+	"github.com/GoogleContainerTools/skaffold/v2/testutil"
 )
 
 func TestRun(t *testing.T) {
