@@ -318,6 +318,14 @@ func TestGetBuildArgs(t *testing.T) {
 			},
 			want: []string{"--foo", "--bar"},
 		},
+		{
+			description: "expand env for CLI flags",
+			artifact: &latest.DockerArtifact{
+				CliFlags: []string{"--cache-to=type=registry,ref={{ .IMAGE_REPO }}/cache-image:cache"},
+			},
+			env:  []string{"IMAGE_REPO=docker.io/library"},
+			want: []string{"--cache-to=type=registry,ref=docker.io/library/cache-image:cache"},
+		},
 		{
 			description: "target",
 			artifact: &latest.DockerArtifact{
@@ -430,7 +438,7 @@ func TestGetBuildArgs(t *testing.T) {
 				return
 			}
 
-			result, err := ToCLIBuildArgs(test.artifact, args)
+			result, err := ToCLIBuildArgs(test.artifact, args, nil)
 
 			t.CheckError(test.shouldErr, err)
 			if !test.shouldErr {
