@@ -17,6 +17,7 @@ limitations under the License.
 package inspect
 
 import (
+	"errors"
 	"fmt"
 
 	sErrors "github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/errors"
@@ -31,7 +32,7 @@ func BuildEnvAlreadyExists(b BuildEnv, filename string, profile string) error {
 	} else {
 		msg = fmt.Sprintf("trying to create a %q build environment definition that already exists, in profile %q in file %s", b, profile, filename)
 	}
-	return sErrors.NewError(fmt.Errorf(msg),
+	return sErrors.NewError(errors.New(msg),
 		&proto.ActionableErr{
 			Message: msg,
 			ErrCode: proto.StatusCode_INSPECT_BUILD_ENV_ALREADY_EXISTS_ERR,
@@ -52,7 +53,7 @@ func BuildEnvNotFound(b BuildEnv, filename string, profile string) error {
 	} else {
 		msg = fmt.Sprintf("trying to modify a %q build environment definition that doesn't exist, in profile %q in file %s", b, profile, filename)
 	}
-	return sErrors.NewError(fmt.Errorf(msg),
+	return sErrors.NewError(errors.New(msg),
 		&proto.ActionableErr{
 			Message: msg,
 			ErrCode: proto.StatusCode_INSPECT_BUILD_ENV_INCORRECT_TYPE_ERR,
@@ -68,7 +69,7 @@ func BuildEnvNotFound(b BuildEnv, filename string, profile string) error {
 // ProfileNotFound specifies that the target profile doesn't exist
 func ProfileNotFound(profile string) error {
 	msg := fmt.Sprintf("trying to modify a profile %q that doesn't exist", profile)
-	return sErrors.NewError(fmt.Errorf(msg),
+	return sErrors.NewError(errors.New(msg),
 		&proto.ActionableErr{
 			Message: msg,
 			ErrCode: proto.StatusCode_INSPECT_PROFILE_NOT_FOUND_ERR,
