@@ -903,7 +903,7 @@ func fakeCmd(ctx context.Context, _ v1.Pod, _ v1.Container, files syncMap) *exec
 	return exec.CommandContext(ctx, "copy", args...)
 }
 
-var pod = &v1.Pod{
+var runningPod = &v1.Pod{
 	ObjectMeta: metav1.ObjectMeta{
 		Name: "podname",
 	},
@@ -920,23 +920,6 @@ var pod = &v1.Pod{
 	},
 }
 
-var nonRunningPod = &v1.Pod{
-	ObjectMeta: metav1.ObjectMeta{
-		Name: "podname",
-	},
-	Status: v1.PodStatus{
-		Phase: v1.PodPending,
-	},
-	Spec: v1.PodSpec{
-		Containers: []v1.Container{
-			{
-				Name:  "container_name",
-				Image: "gcr.io/k8s-skaffold:123",
-			},
-		},
-	},
-}
-
 func TestPerform(t *testing.T) {
 	tests := []struct {
 		description string
@@ -953,7 +936,7 @@ func TestPerform(t *testing.T) {
 			description: "no error",
 			image:       "gcr.io/k8s-skaffold:123",
 			files:       syncMap{"test.go": {"/test.go"}},
-			pod:         pod,
+			pod:         runningPod,
 			cmdFn:       fakeCmd,
 			expected:    []string{"copy test.go /test.go"},
 		},
@@ -961,7 +944,7 @@ func TestPerform(t *testing.T) {
 			description: "cmd error",
 			image:       "gcr.io/k8s-skaffold:123",
 			files:       syncMap{"test.go": {"/test.go"}},
-			pod:         pod,
+			pod:         runningPod,
 			cmdFn:       fakeCmd,
 			cmdErr:      fmt.Errorf(""),
 			shouldErr:   true,
@@ -970,24 +953,24 @@ func TestPerform(t *testing.T) {
 			description: "client error",
 			image:       "gcr.io/k8s-skaffold:123",
 			files:       syncMap{"test.go": {"/test.go"}},
-			pod:         pod,
+			pod:         runningPod,
 			cmdFn:       fakeCmd,
 			clientErr:   fmt.Errorf(""),
 			shouldErr:   true,
 		},
+		{
+			description: "pod not running",
+			image:       "gcr.io/k8s-skaffold:123",
+			files:       syncMap{"test.go": {"/test.go"}},
+			pod:         nil,
+			cmdFn:       fakeCmd,
+			shouldErr:   true,
+		},
 		{
 			description: "no copy",
 			image:       "gcr.io/different-pod:123",
 			files:       syncMap{"test.go": {"/test.go"}},
-			pod:         pod,
-			cmdFn:       fakeCmd,
-			shouldErr:   true,
-		},
-		{
-			description: "Skip sync when pod is not running",
-			image:       "gcr.io/k8s-skaffold:123",
-			files:       syncMap{"test.go": {"/test.go"}},
-			pod:         nonRunningPod,
+			pod:         runningPod,
 			cmdFn:       fakeCmd,
 			shouldErr:   true,
 		},
@@ -998,6 +981,10 @@ func TestPerform(t *testing.T) {
 
 			t.Override(&util.DefaultExecCommand, cmdRecord)
 			t.Override(&client.Client, func(string) (kubernetes.Interface, error) {
+				if test.pod == nil {
+					return fake.NewSimpleClientset(), nil
+				}
+
 				return fake.NewSimpleClientset(test.pod), test.clientErr
 			})
 
