@@ -24,6 +24,7 @@ import (
 	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
 	v1 "github.com/google/go-containerregistry/pkg/v1"
+	dockerspec "github.com/moby/docker-image-spec/specs-go/v1"
 
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/deploy/label"
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/docker"
@@ -65,7 +66,7 @@ func (fd *fakeDockerDaemon) Run(ctx context.Context, out io.Writer, opts docker.
 
 func (fd *fakeDockerDaemon) ImageInspectWithRaw(ctx context.Context, image string) (types.ImageInspect, []byte, error) {
 	return types.ImageInspect{
-		Config: &container.Config{},
+		Config: &dockerspec.DockerOCIImageConfig{},
 	}, []byte{}, nil
 }
 
